==> sqlitewrapper-0.1.2.tar.gz: sqlitewrapper-0.1.2/sqlitewrapper/__init__.py <==
"""
MIT License

Copyright (c) 2023 Jude

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from . import databaseobjects, errors
from . import datatypes as types
from .databaseobjects import DatabaseObject, TableObject

__version__ = '0.1.2'

def open(path, table=None, daemon=True, await_completion=True) -> DatabaseObject or TableObject:
    """ Opens a database or table object. """
    database = DatabaseObject(path, daemon, await_completion)
    if table is None:
        return database
    return TableObject(database, table)

==> sqlitewrapper-0.1.3.tar.gz: sqlitewrapper-0.1.3/sqlitewrapper/__init__.py <==
"""
MIT License

Copyright (c) 2023 Jude

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.
"""

from . import databaseobjects, errors
from . import datatypes as types
from .databaseobjects import DatabaseObject, TableObject

__version__ = '0.1.3'

def open(path, table=None, separate_thread=True, await_completion=True) -> DatabaseObject or TableObject:
    """ Opens a database or table object. """
    database = DatabaseObject(path, separate_thread, await_completion)
    if table is None:
        return database
    return TableObject(database, table)
